stalker.core.mixins.TaskMixin — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.mixins.TaskMixin

class `stalker.core.mixins.` `TaskMixin`(tasks=[], **kwargs)

  Bases: `object`

  Gives the abilitiy to connect to a list of taks to the mixed in object.

  Parameters: | tasks (list) – The list of `Task`s. Should be a list of `Task` instances. Default value is an empty list.

  `__init__`(tasks=[], **kwargs)

  Methods

  `__init__`(**kwargs[, tasks]) |

  Attributes

  `tasks` | The list of `Task` instances.

  `tasks`

    The list of `Task` instances.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »